From: "tip-bot for H. Peter Anvin" <hpa@zytor.com>
To: linux-tip-commits@vger.kernel.org
Cc: linux-kernel@vger.kernel.org, hpa@zytor.com, mingo@redhat.com,
steiner@sgi.com, suresh.b.siddha@intel.com, tglx@linutronix.de
Subject: [tip:x86/mm] x86, mm: Call is_untracked_pat_range() rather than is_ISA_range()
Date: Tue, 24 Nov 2009 01:12:46 GMT [thread overview]
Message-ID: <tip-55a6ca25472ee01574bfc24d23b7f5fa09cc38cf@git.kernel.org> (raw)
In-Reply-To: <20091119202341.GA4420@sgi.com>
Commit-ID: 55a6ca25472ee01574bfc24d23b7f5fa09cc38cf
Gitweb: http://git.kernel.org/tip/55a6ca25472ee01574bfc24d23b7f5fa09cc38cf
Author: H. Peter Anvin <hpa@zytor.com>
AuthorDate: Mon, 23 Nov 2009 15:12:07 -0800
Committer: H. Peter Anvin <hpa@zytor.com>
CommitDate: Mon, 23 Nov 2009 17:09:59 -0800
x86, mm: Call is_untracked_pat_range() rather than is_ISA_range()
Checkin fd12a0d69aee6d90fa9b9890db24368a897f8423 made the PAT
untracked range a platform configurable, but missed on occurrence of
is_ISA_range() which still refers to PAT-untracked memory, and
therefore should be using the configurable.
Signed-off-by: H. Peter Anvin <hpa@zytor.com>
Cc: Jack Steiner <steiner@sgi.com>
Cc: Suresh Siddha <suresh.b.siddha@intel.com>
LKML-Reference: <20091119202341.GA4420@sgi.com>
---
arch/x86/include/asm/pgtable.h | 6 ++++--
1 files changed, 4 insertions(+), 2 deletions(-)
diff --git a/arch/x86/include/asm/pgtable.h b/arch/x86/include/asm/pgtable.h
index af6fd36..1de2094 100644
--- a/arch/x86/include/asm/pgtable.h
+++ b/arch/x86/include/asm/pgtable.h
@@ -16,6 +16,8 @@
#ifndef __ASSEMBLY__
+#include <asm/x86_init.h>
+
/*
* ZERO_PAGE is a global shared page that is always zero: used
* for zero-mapped memory areas etc..
@@ -270,9 +272,9 @@ static inline int is_new_memtype_allowed(u64 paddr, unsigned long size,
unsigned long new_flags)
{
/*
* PAT type is always WB for ISA. So no need to check.
*/
- if (is_ISA_range(paddr, paddr + size - 1))
+ if (x86_platform.is_untracked_pat_range(paddr, paddr + size - 1))
return 1;
/*
next prev parent reply other threads:[~2009-11-24 1:13 UTC|newest]
Thread overview: 13+ messages / expand[flat|nested] mbox.gz Atom feed top
2009-10-29 18:47 [PATCH] x86: UV SGI, Don't track GRU space in PAT Jack Steiner
2009-11-08 12:06 ` Ingo Molnar
2009-11-11 18:30 ` Jack Steiner
2009-11-17 21:23 ` [PATCH v2] " Jack Steiner
2009-11-17 22:21 ` H. Peter Anvin
2009-11-19 20:23 ` [PATCH v3] " Jack Steiner
2009-11-23 18:25 ` Ingo Molnar
2009-11-23 18:55 ` [tip:x86/mm] x86: UV SGI: " tip-bot for Jack Steiner
2009-11-24 1:12 ` tip-bot for H. Peter Anvin [this message]
2009-11-24 1:13 ` [tip:x86/mm] x86, mm: is_untracked_pat_range() takes a normal semiclosed range tip-bot for H. Peter Anvin
2009-11-24 1:13 ` [tip:x86/mm] x86: Change is_ISA_range() into an inline function tip-bot for H. Peter Anvin
2009-11-24 1:13 ` [tip:x86/mm] x86, platform: Change is_untracked_pat_range() to bool; cleanup init tip-bot for H. Peter Anvin
2009-12-01 7:36 ` [tip:x86/mm] x86, mm: Correct the implementation of is_untracked_pat_range() tip-bot for H. Peter Anvin
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=tip-55a6ca25472ee01574bfc24d23b7f5fa09cc38cf@git.kernel.org \
--to=hpa@zytor.com \
--cc=linux-kernel@vger.kernel.org \
--cc=linux-tip-commits@vger.kernel.org \
--cc=mingo@redhat.com \
--cc=steiner@sgi.com \
--cc=suresh.b.siddha@intel.com \
--cc=tglx@linutronix.de \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -270,9 +272,9 @@ static inline int is_new_memtype_allowed(u64 paddr, unsigned long size,
{
/*
- * PAT type is always WB for ISA. So no need to check.
+ * PAT type is always WB for untracked ranges, so no need to check.
*/
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox